@@ -7,6 +7,8 @@
 SEXP agg_ppm_c(SEXP file, SEXP width, SEXP height, SEXP pointsize, SEXP bg, 
                SEXP res) {
   int bgCol = RGBpar(bg, 0);
+  
+  BEGIN_CPP
   AggDevicePpmNoAlpha* device = new AggDevicePpmNoAlpha(
     CHAR(STRING_ELT(file, 0)), 
     INTEGER(width)[0], 
@@ -16,6 +18,7 @@ SEXP agg_ppm_c(SEXP file, SEXP width, SEXP height, SEXP pointsize, SEXP bg,
     REAL(res)[0]
   );
   makeDevice<AggDevicePpmNoAlpha>(device, "agg_ppm");
+  END_CPP
   
   return R_NilValue;
 }
