@@ -6,7 +6,8 @@
 #include <utility>
 #include <unordered_map>
 
-#include <R.h>
+#define R_NO_REMAP
+
 #include <Rinternals.h>
 #include <R_ext/GraphicsEngine.h>
 
@@ -18,6 +19,15 @@
 #include "agg_renderer_base.h"
 #include "agg_renderer_scanline.h"
 
+// Define a C++ try-catch macro to guard C++ calls
+#define BEGIN_CPP try {
+
+#define END_CPP                                                                \
+}                                                                              \
+catch (std::exception & e) {                                                   \
+  Rf_error("C++ exception: %s", e.what());                                     \
+}                                                                              \
+
 #define R_USE_PROTOTYPES 1
 typedef agg::pixfmt_rgb24_pre                   pixfmt_type_24;
 typedef agg::pixfmt_rgba32_pre                  pixfmt_type_32;
@@ -30,32 +40,6 @@ typedef agg::pixfmt_abgr32                      pixfmt_r_raster;
 typedef agg::pixfmt_rgba32                      pixfmt_r_raster;
 #endif
 
-
-typedef std::tuple<std::string, int, int> font_key;
-
-struct key_hash : public std::unary_function<font_key, std::size_t>
-{
-  inline std::size_t operator()(const font_key& k) const
-  {
-    return std::get<0>(k)[0] ^ std::get<1>(k) ^ std::get<2>(k);
-  }
-};
-
-struct key_equal : public std::binary_function<font_key, font_key, bool>
-{
-  inline bool operator()(const font_key& v0, const font_key& v1) const
-  {
-    return (
-        std::get<0>(v0) == std::get<0>(v1) &&
-          std::get<1>(v0) == std::get<1>(v1) &&
-          std::get<2>(v0) == std::get<2>(v1)
-    );
-  }
-};
-
-typedef std::unordered_map<font_key, std::pair< std::string, int >, key_hash, key_equal> font_map;
-
-
 // pixfmt agnosting demultiplying
 template<typename PIXFMT>
 inline void demultiply(PIXFMT* pixfmt) {
@@ -80,6 +64,8 @@ SEXP agg_supertransparent_c(SEXP file, SEXP width, SEXP height, SEXP pointsize,
                             SEXP bg, SEXP res, SEXP alpha_mod);
 SEXP agg_tiff_c(SEXP file, SEXP width, SEXP height, SEXP pointsize, SEXP bg, 
                 SEXP res, SEXP bit, SEXP compression, SEXP encoding);
+SEXP agg_jpeg_c(SEXP file, SEXP width, SEXP height, SEXP pointsize, SEXP bg, 
+                SEXP res, SEXP quality, SEXP smoothing, SEXP method);
 SEXP agg_capture_c(SEXP name, SEXP width, SEXP height, SEXP pointsize, SEXP bg, 
                    SEXP res);
 
